package ru.ulstu.extractor.db;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import ru.ulstu.extractor.model.Commit;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

@Repository
public class CommitRepository {
    private final static String SQL_SELECT_COMMITS = "SELECT * FROM commit";
    private final static String SQL_INSERT_COMMITS = "INSERT INTO commit (hash, date, author, message) " +
            "VALUES (?, ?, ?, ?)";
    private final JdbcTemplate jdbcTemplate;

    public CommitRepository(JdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    private static class CommitRowMapper implements RowMapper<Commit> {

        @Override
        public Commit mapRow(ResultSet rs, int rowNum) throws SQLException {
            return new Commit(rs.getString("message"),
                    rs.getString("author"),
                    rs.getDate("date"));
        }
    }

    public List<Commit> getCommits() {
        return jdbcTemplate.query(SQL_SELECT_COMMITS, new CommitRowMapper());
    }

    public void saveCommit(Commit commit) {
        jdbcTemplate.update(SQL_INSERT_COMMITS, "", commit.getDate(),
                commit.getAuthor(),
                commit.getMessage());
    }
}
